@@ -217,6 +217,12 @@ class TestListAudit(api_base.FunctionalTest):
         uuids = [s['goal_uuid'] for s in response['audits']]
         self.assertEqual(sorted(goal_list), uuids)
 
+    def test_sort_key_validation(self):
+        response = self.get_json(
+            '/audits?sort_key=%s' % 'bad_name',
+            expect_errors=True)
+        self.assertEqual(400, response.status_int)
+
     def test_links(self):
         uuid = utils.generate_uuid()
         obj_utils.create_test_audit(
@@ -491,6 +497,7 @@ class TestPost(api_base.FunctionalTest):
         del audit_dict['interval']
         del audit_dict['scope']
         del audit_dict['next_run_time']
+        del audit_dict['hostname']
 
         response = self.post_json('/audits', audit_dict)
         self.assertEqual('application/json', response.content_type)
@@ -534,6 +541,7 @@ class TestPost(api_base.FunctionalTest):
         del audit_dict['interval']
         del audit_dict['scope']
         del audit_dict['next_run_time']
+        del audit_dict['hostname']
         # Make the audit template UUID some garbage value
         audit_dict['audit_template_uuid'] = (
             '01234567-8910-1112-1314-151617181920')
@@ -557,6 +565,7 @@ class TestPost(api_base.FunctionalTest):
         del audit_dict['interval']
         del audit_dict['scope']
         del audit_dict['next_run_time']
+        del audit_dict['hostname']
         with mock.patch.object(self.dbapi, 'create_audit',
                                wraps=self.dbapi.create_audit) as cn_mock:
             response = self.post_json('/audits', audit_dict)
@@ -575,6 +584,7 @@ class TestPost(api_base.FunctionalTest):
         del audit_dict['interval']
         del audit_dict['scope']
         del audit_dict['next_run_time']
+        del audit_dict['hostname']
 
         response = self.post_json('/audits', audit_dict)
         self.assertEqual('application/json', response.content_type)
@@ -592,6 +602,7 @@ class TestPost(api_base.FunctionalTest):
         del audit_dict['state']
         del audit_dict['scope']
         del audit_dict['next_run_time']
+        del audit_dict['hostname']
         audit_dict['audit_type'] = objects.audit.AuditType.CONTINUOUS.value
         audit_dict['interval'] = '1200'
 
@@ -613,6 +624,7 @@ class TestPost(api_base.FunctionalTest):
         del audit_dict['state']
         del audit_dict['scope']
         del audit_dict['next_run_time']
+        del audit_dict['hostname']
         audit_dict['audit_type'] = objects.audit.AuditType.CONTINUOUS.value
         audit_dict['interval'] = '* * * * *'
 
@@ -634,6 +646,7 @@ class TestPost(api_base.FunctionalTest):
         del audit_dict['state']
         del audit_dict['scope']
         del audit_dict['next_run_time']
+        del audit_dict['hostname']
         audit_dict['audit_type'] = objects.audit.AuditType.CONTINUOUS.value
         audit_dict['interval'] = 'zxc'
 
@@ -656,6 +669,7 @@ class TestPost(api_base.FunctionalTest):
         del audit_dict['interval']
         del audit_dict['scope']
         del audit_dict['next_run_time']
+        del audit_dict['hostname']
 
         response = self.post_json('/audits', audit_dict, expect_errors=True)
         self.assertEqual(400, response.status_int)
@@ -675,6 +689,7 @@ class TestPost(api_base.FunctionalTest):
         audit_dict['audit_type'] = objects.audit.AuditType.ONESHOT.value
         del audit_dict['scope']
         del audit_dict['next_run_time']
+        del audit_dict['hostname']
 
         response = self.post_json('/audits', audit_dict, expect_errors=True)
         self.assertEqual(400, response.status_int)
@@ -692,6 +707,7 @@ class TestPost(api_base.FunctionalTest):
             del audit_dict['interval']
             del audit_dict['scope']
             del audit_dict['next_run_time']
+            del audit_dict['hostname']
             response = self.post_json('/audits', audit_dict)
             de_mock.assert_called_once_with(mock.ANY, response.json['uuid'])
 
@@ -716,6 +732,7 @@ class TestPost(api_base.FunctionalTest):
         del audit_dict['interval']
         del audit_dict['scope']
         del audit_dict['next_run_time']
+        del audit_dict['hostname']
 
         response = self.post_json('/audits', audit_dict, expect_errors=True)
         self.assertEqual('application/json', response.content_type)
@@ -738,6 +755,7 @@ class TestPost(api_base.FunctionalTest):
         del audit_dict['interval']
         del audit_dict['scope']
         del audit_dict['next_run_time']
+        del audit_dict['hostname']
 
         response = self.post_json('/audits', audit_dict, expect_errors=True)
         self.assertEqual('application/json', response.content_type)
@@ -760,7 +778,7 @@ class TestPost(api_base.FunctionalTest):
 
         audit_dict['audit_template_uuid'] = audit_template['uuid']
         del_keys = ['uuid', 'goal_id', 'strategy_id', 'state', 'interval',
-                    'scope', 'next_run_time']
+                    'scope', 'next_run_time', 'hostname']
         for k in del_keys:
             del audit_dict[k]
 
@@ -816,12 +834,13 @@ class TestPost(api_base.FunctionalTest):
         audit_dict = post_get_test_audit()
         normal_name = 'this audit name is just for test'
         # long_name length exceeds 63 characters
-        long_name = normal_name+audit_dict['uuid']
+        long_name = normal_name + audit_dict['uuid']
         del audit_dict['uuid']
         del audit_dict['state']
         del audit_dict['interval']
         del audit_dict['scope']
         del audit_dict['next_run_time']
+        del audit_dict['hostname']
 
         audit_dict['name'] = normal_name
         response = self.post_json('/audits', audit_dict)
@@ -948,6 +967,7 @@ class TestAuditPolicyEnforcement(api_base.FunctionalTest):
         del audit_dict['state']
         del audit_dict['scope']
         del audit_dict['next_run_time']
+        del audit_dict['hostname']
         self._common_policy_check(
             "audit:create", self.post_json, '/audits', audit_dict,
             expect_errors=True)
